==> tui-chart-3.0.1.jar: META-INF/resources/webjars/tui-chart/3.0.1/test/helpers/chartExporter.spec.js <==
/**
 * @fileoverview Test for chartExporter.
 * @author NHN Ent.
 *         FE Development Lab <dl_javascript@nhnent.com>
 */

'use strict';

var chartExporter = require('../../src/js/helpers/chartExporter');
var imageExporter = require('../../src/js/helpers/imageExporter');
var dataExporter = require('../../src/js/helpers/dataExporter');

describe('Test for chartExporter', function() {
    var rawData = [];
    var downloadOption = {
        xls: {},
        csv: {},
        png: {},
        jpeg: {}
    };
    var canvas = document.createElement('canvas');

    beforeEach(function() {
        spyOn(imageExporter, 'downloadImage');
        spyOn(dataExporter, 'downloadData');
    });
    describe('exportChart()', function() {
        it('should download data when file extension is xls.', function() {
            chartExporter.exportChart('myFile', 'xls', rawData, null, downloadOption);
            expect(dataExporter.downloadData).toHaveBeenCalledWith('myFile', 'xls', rawData, downloadOption.xls);
        });
        it('should download data when file extension is csv.', function() {
            chartExporter.exportChart('myFile', 'csv', rawData, null, downloadOption);
            expect(dataExporter.downloadData).toHaveBeenCalledWith('myFile', 'csv', rawData, downloadOption.csv);
        });
        it('should download image when file extension is png.', function() {
            chartExporter.exportChart('myFile', 'png', rawData, canvas, null);
            expect(imageExporter.downloadImage).toHaveBeenCalledWith('myFile', 'png', canvas);
        });
        it('should download image when file extension is png.', function() {
            chartExporter.exportChart('myFile', 'jpeg', rawData, canvas, null);
            expect(imageExporter.downloadImage).toHaveBeenCalledWith('myFile', 'jpeg', canvas);
        });
        it('should not download file when extension neither image or data.', function() {
            chartExporter.exportChart('myFile', 'exe', rawData, canvas, null);
            expect(imageExporter.downloadImage).not.toHaveBeenCalled();
            expect(dataExporter.downloadData).not.toHaveBeenCalled();
        });
    });
});

==> tui-chart-3.4.1.jar: META-INF/resources/webjars/tui-chart/3.4.1/test/helpers/chartExporter.spec.js <==
/**
 * @fileoverview Test for chartExporter.
 * @author NHN Ent.
 *         FE Development Lab <dl_javascript@nhnent.com>
 */

import chartExporter from '../../src/js/helpers/chartExporter';
import imageExporter from '../../src/js/helpers/imageExporter';
import dataExporter from '../../src/js/helpers/dataExporter';

describe('Test for chartExporter', () => {
    const rawData = [];
    const downloadOption = {
        xls: {},
        csv: {},
        png: {},
        jpeg: {}
    };
    const canvas = document.createElement('canvas');

    beforeEach(() => {
        spyOn(imageExporter, 'downloadImage');
        spyOn(dataExporter, 'downloadData');
    });
    describe('exportChart()', () => {
        it('should download data when file extension is xls.', () => {
            chartExporter.exportChart('myFile', 'xls', rawData, null, downloadOption);
            expect(dataExporter.downloadData).toHaveBeenCalledWith('myFile', 'xls', rawData, downloadOption.xls);
        });
        it('should download data when file extension is csv.', () => {
            chartExporter.exportChart('myFile', 'csv', rawData, null, downloadOption);
            expect(dataExporter.downloadData).toHaveBeenCalledWith('myFile', 'csv', rawData, downloadOption.csv);
        });
        it('should download image when file extension is png.', () => {
            chartExporter.exportChart('myFile', 'png', rawData, canvas, null);
            expect(imageExporter.downloadImage).toHaveBeenCalledWith('myFile', 'png', canvas);
        });
        it('should download image when file extension is png.', () => {
            chartExporter.exportChart('myFile', 'jpeg', rawData, canvas, null);
            expect(imageExporter.downloadImage).toHaveBeenCalledWith('myFile', 'jpeg', canvas);
        });
        it('should not download file when extension neither image or data.', () => {
            chartExporter.exportChart('myFile', 'exe', rawData, canvas, null);
            expect(imageExporter.downloadImage).not.toHaveBeenCalled();
            expect(dataExporter.downloadData).not.toHaveBeenCalled();
        });
    });
});
